info = {
    "desc":"""利用此程式可以將所有的圖片轉換成 ASCII ART 形式的文字檔。""",
    "file help": "欲轉換的圖片",
    "out file help": "輸出檔案名稱",
    "scale help": "輸入為兩個 int 正整數(Width, Height), 每個 ASCII 文字代表的像素(pixels)寬(Width)與高(Height)",
}


__all__ = ["info"]